| BPS_combine | R Documentation |
Combine subset models wiht BPS
BPS_combine(fit_list, K, rp)
fit_list |
list K fitted model outputs composed by two elements each: first named |
K |
integer number of folds |
rp |
double percentage of observations to take into account for optimization ( |
matrix posterior predictive density evaluations (each columns represent a different model)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.