Compute the BPS posterior samples given a set of stacking weights
BPS_postdraws_MvT.RdCompute the BPS posterior samples given a set of stacking weights
Arguments
- data
list two elements: first named \(Y\), second named \(X\)
- priors
list priors: named \(\mu_B\),\(V_r\),\(\Psi\),\(\nu\)
- coords
matrix sample coordinates for X and Y
- hyperpar
list two elemets: first named \(\alpha\), second named \(\phi\)
- W
matrix set of stacking weights
- R
integer number of desired samples
- par
if
TRUEonly \(\beta\) and \(\Sigma\) are sampled (\(\omega\) is omitted)
Value
matrix BPS posterior samples