Compute the parameters for the posteriors distribution of \(\beta\) and \(\Sigma\) (i.e. updated parameters)
fit_cpp_MvT.RdCompute the parameters for the posteriors distribution of \(\beta\) and \(\Sigma\) (i.e. updated parameters)
Value
list posterior update parameters