Return the CV predictive density evaluations for all the model combinations
models_dens_MvT.RdReturn the CV predictive density evaluations for all the model combinations
Arguments
- data
list two elements: first named \(Y\), second named \(X\)
- priors
list priors: named \(\mu_B\),\(V_r\),\(\Psi\),\(\nu\)
- coords
matrix sample coordinates for X and Y
- hyperpar
list two elemets: first named \(\alpha\), second named \(\phi\)
- useKCV
if
TRUEK-fold cross validation is used instead of LOOCV (nodefault)- K
integer number of folds
Value
matrix posterior predictive density evaluations (each columns represent a different model)