Skip to contents

Combine subset models wiht BPS

Usage

BPS_combine(fit_list, K, rp)

Arguments

fit_list

list K fitted model outputs composed by two elements each: first named \(epd\), second named \(W\)

K

integer number of folds

rp

double percentage of observations to take into account for optimization (default=1)

Value

matrix posterior predictive density evaluations (each columns represent a different model)