BPS_post_MvT: Perform the BPS sampling from posterior and posterior...

View source: R/RcppExports.R

BPS_post_MvTR Documentation

Perform the BPS sampling from posterior and posterior predictive given a set of stacking weights

Description

Perform the BPS sampling from posterior and posterior predictive given a set of stacking weights

Usage

BPS_post_MvT(data, X_u, priors, coords, crd_u, hyperpar, W, R)

Arguments

data

list two elements: first named Y, second named X

X_u

matrix unobserved instances covariate matrix

priors

list priors: named \mu_B,V_r,\Psi,\nu

coords

matrix sample coordinates for X and Y

crd_u

matrix unboserved instances coordinates

hyperpar

list two elemets: first named \alpha, second named \phi

W

matrix set of stacking weights

R

integer number of desired samples

Value

list BPS posterior predictive samples


spBPS documentation built on March 19, 2026, 5:07 p.m.