Solver for Bayesian Predictive Stacking of Predictive densities convex optimization problem
conv_opt.RdSolver for Bayesian Predictive Stacking of Predictive densities convex optimization problem
Arguments
- scores
matrix \(N \times K\) of expected predictive density evaluations for the K models considered
Value
W matrix of Bayesian Predictive Stacking weights for the K models considered